@@ -1,6 +1,6 @@
 import six
 from sqlalchemy import types
-from sqlalchemy_utils import ImproperlyConfigured
+from sqlalchemy_utils.exceptions import ImproperlyConfigured
 from .scalar_coercible import ScalarCoercible
 
 colour = None
